author | Marc Fournier <marc.fournier@camptocamp.com> | |
Tue, 19 May 2015 16:37:19 +0000 (18:37 +0200) | ||
committer | Marc Fournier <marc.fournier@camptocamp.com> | |
Tue, 19 May 2015 16:37:19 +0000 (18:37 +0200) |
1 | 2 | |||
---|---|---|---|---|
src/curl_xml.c | patch | | diff1 | | diff2 | | blob | history |
diff --cc src/curl_xml.c
index 7ca9831f9e85fe95aae6315b702520387686a18f,e96bba3132858dfbe3b7a1fe83eaf376617889e1..e3d37f48e45e3479d509bd9c9714ddad5cd84718
--- 1/src/curl_xml.c
--- 2/src/curl_xml.c
+++ b/src/curl_xml.c
memset (vl->type_instance, 0, sizeof (vl->type_instance));
/* If the base xpath returns more than one block, the result is assumed to be
* a table. The `Instnce' option is not optional in this case. Check for the
* condition and inform the user. */
- if (is_table)
+ if (is_table && (xpath->instance == NULL))
{
WARNING ("curl_xml plugin: "
"Base-XPath %s is a table (more than one result was returned), "
@@
memset (vl->type_instance, 0, sizeof (vl->type_instance));
/* If the base xpath returns more than one block, the result is assumed to be
- * a table. The `Instnce' option is not optional in this case. Check for the
+ * a table. The `Instance' option is not optional in this case. Check for the
* condition and inform the user. */